@@ -3,7 +3,7 @@
 --               GtkAda - Ada95 binding for Gtk+/Gnome               --
 --                                                                   --
 --   Copyright (C) 1998-2000 E. Briot, J. Brobecker and A. Charlet   --
---                Copyright (C) 2000-2008, AdaCore                   --
+--                Copyright (C) 2000-2009, AdaCore                   --
 --                                                                   --
 -- This library is free software; you can redistribute it and/or     --
 -- modify it under the terms of the GNU General Public               --
@@ -591,8 +591,7 @@ ada_initialize_class_record
 
       /* Need to create a new type, otherwise Gtk+ won't free objects of
          this type */
-      new_type = g_type_register_static
-	(ancestor, g_strdup (type_name), class_info, 0);
+      new_type = g_type_register_static (ancestor, type_name, class_info, 0);
       klass = g_type_class_ref (new_type);
 
       g_assert (klass != NULL);
@@ -2235,73 +2234,6 @@ ada_gdk_event_set_message_type (GdkEvent * event, GdkAtom type)
   return 0;
 }
 
-/********************
- * GtkAdjustment
- ********************/
-
-gdouble
-ada_gtk_adjustment_get_page_size (GtkAdjustment * adjustment)
-{
-  return adjustment->page_size;
-}
-
-gdouble
-ada_gtk_adjustment_get_page_increment (GtkAdjustment * adjustment)
-{
-  return adjustment->page_increment;
-}
-
-gdouble
-ada_adjustment_get_lower (GtkAdjustment * adjustment)
-{
-  return adjustment->lower;
-}
-
-gdouble
-ada_adjustment_get_upper (GtkAdjustment * adjustment)
-{
-  return adjustment->upper;
-}
-
-void
-ada_adjustment_set_page_increment (GtkAdjustment * adjustment,
-				   gdouble value)
-{
-  adjustment->page_increment = value;
-}
-
-void
-ada_adjustment_set_step_increment (GtkAdjustment * adjustment,
-				   gdouble value)
-{
-  adjustment->step_increment = value;
-}
-
-void
-ada_gtk_adjustment_set_lower (GtkAdjustment * adjustment, gdouble lower)
-{
-  adjustment->lower = lower;
-}
-
-void
-ada_gtk_adjustment_set_upper (GtkAdjustment * adjustment, gdouble upper)
-{
-  adjustment->upper = upper;
-}
-
-gdouble
-ada_gtk_adjustment_get_step_increment (GtkAdjustment * adjustment)
-{
-  return adjustment->step_increment;
-}
-
-void
-ada_adjustment_set_page_size (GtkAdjustment * adjustment,
-			      gdouble value)
-{
-  adjustment->page_size = value;
-}
-
 /*
  *
  * GtkStyle
@@ -3222,7 +3154,10 @@ ada_list_prev (GList* list)
 gpointer
 ada_list_get_data (GList* list)
 {
-  return list->data;
+  if (list)
+     return list->data;
+  else
+     return NULL;
 }
 
 /**********************************************
@@ -4223,22 +4158,33 @@ ada_gdk_get_window_id (GdkWindow *w)
   return (void *)GDK_WINDOW_HWND (w);
 }
 
+#elif defined (__APPLE__)
+/*  Disable this function under Apple, since under Tiger the call to
+    XWarpPointer requires explicit linker flags pointing to X11 libs,
+    and when using Quartz, there is no X11 lib at all.
+*/
+void
+ada_gdk_move_pointer (gint x, gint y)
+{
+}
+
+void *
+ada_gdk_get_window_id (GdkWindow *w)
+{
+  return NULL;
+}
+
 #else
 #include <gdk/gdkx.h>
 
 void
 ada_gdk_move_pointer (gint x, gint y)
 {
-/*  Disable this function under Apple, since under Tiger the call to
-    XWarpPointer requires explicit linker flags pointing to X11 libs.
-*/
-#ifndef __APPLE__
   GdkDisplay *display = gdk_display_get_default ();
   Display *xdisplay = GDK_DISPLAY_XDISPLAY (display);
   Window xroot_window = GDK_WINDOW_XID (gdk_get_default_root_window ());
 
   XWarpPointer (xdisplay, None, xroot_window, 0, 0, 0, 0, x, y);
-#endif
 }
 
 void *
